summaryrefslogtreecommitdiffstats
path: root/src/engine/SCons/Sig
diff options
context:
space:
mode:
authorSteven Knight <knight@baldmt.com>2002-07-12 06:17:59 (GMT)
committerSteven Knight <knight@baldmt.com>2002-07-12 06:17:59 (GMT)
commit721c0b5439329cce1a68d44c0e58204a83d9d354 (patch)
tree640ad8f81638eaf79461675d47418643fbb2e6b1 /src/engine/SCons/Sig
parent25846c09acbebca4f41664a76dfc6175b3617e90 (diff)
downloadSCons-721c0b5439329cce1a68d44c0e58204a83d9d354.zip
SCons-721c0b5439329cce1a68d44c0e58204a83d9d354.tar.gz
SCons-721c0b5439329cce1a68d44c0e58204a83d9d354.tar.bz2
Added --implicit-deps-unchanged option. Added GetLaunchDir() function. Added SetBuildSignatureType() function. (Anthony Roach)
Diffstat (limited to 'src/engine/SCons/Sig')
-rw-r--r--src/engine/SCons/Sig/__init__.py13
1 files changed, 10 insertions, 3 deletions
diff --git a/src/engine/SCons/Sig/__init__.py b/src/engine/SCons/Sig/__init__.py
index 553c9ce..0e629fb 100644
--- a/src/engine/SCons/Sig/__init__.py
+++ b/src/engine/SCons/Sig/__init__.py
@@ -38,6 +38,10 @@ import time
#XXX Get rid of the global array so this becomes re-entrant.
sig_files = []
+# 1 means use build signature for derived source files
+# 0 means use content signature for derived source files
+build_signature = 1
+
def write():
global sig_files
for sig_file in sig_files:
@@ -359,13 +363,13 @@ class Calculator:
def get_signature(self, node):
"""
Get the appropriate signature for a node.
node - the node
returns - the signature or None if the signature could not
be computed.
- This method does not store the signature in the node and
+ This method does not store the signature in the node or
in the .sconsign file.
"""
@@ -374,7 +378,10 @@ class Calculator:
# directory) so bail right away.
return None
elif node.builder:
- return self.bsig(node)
+ if build_signature:
+ return self.bsig(node)
+ else:
+ return self.csig(node)
elif not node.exists():
return None
else:
@@ -359,13 +363,13 @@ class Calculator:
def get_signature(self, node):
"""
- Get the appropriate signature for a node.
+ Get the appropriate build signature for a node.
node - the node
returns - the signature or None if the signature could not